import { createApp } from 'vue'
import App from './App.vue'
import './index.css'
import router from './router'
import { createPinia } from 'pinia'
import { useBudgetsStore } from './stores/budget';
import { useSessionStore } from './stores/session';
import { useSettingsStore } from './stores/settings';
import { useAccountStore } from './stores/budget-account'

const app = createApp(App)
app.use(router)
app.use(createPinia())
app.mount('#app')

router.beforeEach(async (to, from, next) => {
  const budgetStore = useBudgetsStore();
  await budgetStore.SetCurrentBudget((<string>to.params.budgetid));

  const accountStore = useAccountStore();
  await accountStore.SetCurrentAccount((<string>to.params.budgetid), (<string>to.params.accountid));
  next();
})

function saveStateToLocalStorage() {
    const sessionStore = useSessionStore();
    const budgetStore = useBudgetsStore();
    const accountStore = useAccountStore();
    const settingsStore = useSettingsStore();
    let persistedState = {
        Session: sessionStore,
        CurrentBudgetID: budgetStore.CurrentBudgetID,
        CurrentAccountID: accountStore.CurrentAccountID,
        ExpandMenu: settingsStore.ExpandMenu,
        ShowMenu: settingsStore.ShowMenu
    }
    localStorage.setItem('store', JSON.stringify(persistedState));

}

useSettingsStore().$subscribe(() => saveStateToLocalStorage);
useBudgetsStore().$subscribe(() => saveStateToLocalStorage);
useSessionStore().$subscribe(() => saveStateToLocalStorage);