import { defineStore } from 'pinia'

interface State {
    Token: string | null
    User: string | null
    Budgets: Map<string, Budget>,
}

export interface Budget {
    ID: string
    Name: string
    AvailableBalance: number
}

export const useSessionStore = defineStore('session', {
    // convert to a function
    state: (): State => ({
        Token: null,
        User: null,
        Budgets: new Map<string, Budget>(),
    }),
    getters: {
        BudgetsList: (state) => state.Budgets.values(),
        AuthHeaders: (state) => ({'Authorization': 'Bearer ' + state.Token}),
        LoggedIn: (state) => state.Token != null,
    },
    actions: {
        setTitle(title : string) {
            document.title = "Budgeteer - " + title;
        },
        loginSuccess(x : any) {
            this.User = x.User;
            this.Token = x.Token;
            this.Budgets = x.Budgets;
        },
        login(login: any) {
            return fetch("/api/v1/user/login", { method: "POST", body: JSON.stringify(login) })
                .then(x => x.json())
                .then(x => this.loginSuccess(x));
        },
        register(login : any) {
            return fetch("/api/v1/user/register", { method: "POST", body: JSON.stringify(login) })
                .then(x => x.json())
                .then(x => this.loginSuccess(x))
        },
        // easily reset state using `$reset`
        logout() {
            this.$reset()
        }
    }
})
